@@ -1,6 +1,6 @@
 package Mail::DMARC;
 {
-  $Mail::DMARC::VERSION = '0.20130517';
+  $Mail::DMARC::VERSION = '0.20130520';
 }
 use strict;
 use warnings;
@@ -147,23 +147,35 @@ Mail::DMARC - Perl implementation of DMARC
 
 =head1 VERSION
 
-version 0.20130517
+version 0.20130520
 
 =head1 SYNOPSIS
 
 DMARC: Domain-based Message Authentication, Reporting and Conformance
 
-A reliable means to authenticate who mail is from, at internet scale.
-
 =head1 DESCRIPTION
 
-Determine if:
+This module is a suite of tools for implementing DMARC. It adheres very tightly to the 2013 DMARC draft, intending to implement every MUST and every SHOULD.
 
-    a. the header_from domain exists
-    b. the header_from domain publishes a DMARC policy
-    c. does the message conform to the published policy?
+This module can be used...
 
-Results of DMARC processing are stored in a L<Mail::DMARC::Result> object.
+=over 4
+
+by MTAs and filtering tools such as SpamAssassin to validate that incoming messages are aligned with the purported senders policies.
+
+by an email sender that wishes to receive DMARC reports from other mail servers.
+
+=back
+
+When a message arrives via SMTP, the MTA or filtering application can pass in a small amount of metadata about the connection (envelope details, SPF results, and DKIM results) to Mail::DMARC. When the B<validate> method is called, the Mail::DMARC will determine if:
+
+ a. the header_from domain exists
+ b. the header_from domain publishes a DMARC policy
+ c. if not, end processing
+ d. does the message conform to the published policy?
+ e. did the policy request reporting? If so, save details.
+
+The validation results are stored in a L<Mail::DMARC::Result> object. Example inspection of a result object is shown in HOW TO USE. If a report was requested, it was saved via L<Mail::DMARC::Report::Store>. A SQL implementation is provided and tested with SQLite and MySQL. ANSI SQL queries syntax is preferred, making it straight forward to extend to other RDBMS.
 
 =head1 HOW TO USE
 
@@ -187,29 +199,29 @@ Results of DMARC processing are stored in a L<Mail::DMARC::Result> object.
      ...continue normal processing...
  };
 
-There's a lot of information available in the $result object. See L<Mail::DMARC::Result> page for complete details.
+There is more information available in the $result object. See L<Mail::DMARC::Result> for complete details.
 
 =head1 CLASSES
 
-L<Mail::DMARC> - A perl implementation of the DMARC draft
+L<Mail::DMARC> - the perl interface for DMARC
 
-L<Mail::DMARC::Policy> - a DMARC policy, as published or retrieved via DNS
+L<Mail::DMARC::Policy> - a DMARC policy
 
-L<Mail::DMARC::PurePerl> - a perl DMARC implementation
+L<Mail::DMARC::PurePerl> - Pure Perl implementation of DMARC
 
-L<Mail::DMARC::Result> - results of DMARC processing
+L<Mail::DMARC::Result> - the results of applying policy
 
 L<Mail::DMARC::Report> - Reporting: the R in DMARC
 
 =over 4
 
-L<Mail::DMARC::Report::Send> - deliver formatted reports via SMTP & HTTP
+L<Mail::DMARC::Report::Send> - send reports via SMTP & HTTP
 
-L<Mail::DMARC::Report::Receive> - parse incoming email and HTTP reports to store
+L<Mail::DMARC::Report::Receive> - receive and store reports from email, HTTP
 
-L<Mail::DMARC::Report::Store> - a persistent data store for DMARC reports
+L<Mail::DMARC::Report::Store> - a persistent data store for aggregate reports
 
-L<Mail::DMARC::Report::View> - CLI and (eventually) CGI methods for report viewing
+L<Mail::DMARC::Report::View> - CLI and CGI methods for viewing reports
 
 =back
 
@@ -346,6 +358,40 @@ The scope of the checked domain: mfrom, helo
 
 The SPF result code: none, neutral, pass, fail, softfail, temperror, or permerror.
 
+=head1 DESIGN & GOALS
+
+=head2 Correct
+
+The DMARC spec is lengthy and evolving, making correctness a moving target. In cases where correctness is ambiguous, options are generally provided.
+
+=head2 Easy to use
+
+The effectiveness of DMARC will improve significantly as adoption increases. Proving an implementation of DMARC that SMTP utilities like SpamAssassin, amavis, and qpsmtpd can consume will aid adoption.
+
+=head2 Maintainable
+
+Since DMARC is evolving, this implementation aims to be straight forward and dare I say, easy, to alter and extend. The programming style is primarily OO, which carries a small performance penalty but large dividends in maintainability.
+
+When multiple options are available, such as when sending reports via SMTP or HTTP, calls are made to the parent Send class, which brokers the request. When storing reports, calls are made to the Store class, which dispatches to the SQL class. The idea is that if someone desired a data store other than the many provided by perl's DBI class, they could easily implement their own. If you do, please fork it on GitHub and share.
+
+=head2 Fast
+
+I have conducted no optimization nor benchmarking and I am not a High Performance Perl expert. If you deploy this in an environment where performance is not sufficient, please do submit patches that are aligned with these goals.
+
+=head1 SEE ALSO
+
+Mail::DMARC on GitHub: https://github.com/msimerson/mail-dmarc
+
+Mar 13, 2013 Draft: http://tools.ietf.org/html/draft-kucherawy-dmarc-base-00
+
+Mar 30, 2012 Draft: http://www.dmarc.org/draft-dmarc-base-00-02.txt
+
+=head1 HISTORY
+
+The daddy of this perl module was a DMARC module for the qpsmtpd MTA.
+
+Qpsmtpd plugin: https://github.com/qpsmtpd-dev/qpsmtpd-dev/blob/master/plugins/dmarc
+
 =head1 AUTHORS
 
 =over 4
