@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::Store::SQL;
 {
-  $Mail::DMARC::Report::Store::SQL::VERSION = '0.20130517';
+  $Mail::DMARC::Report::Store::SQL::VERSION = '0.20130520';
 }
 use strict;
 use warnings;
@@ -13,30 +13,47 @@ use File::ShareDir;
 use parent 'Mail::DMARC::Base';
 
 sub save_author {
-    my ($self,$meta,$pol_pub,$records) = @_;
+    my ($self,$meta,$policy,$records) = @_;
+# Reports that others generate, when they receive email purporting to be us
 
-    $self->insert_author_report($meta,$pol_pub) or croak "failed to create report!";
+    my %required = (
+        meta    => [ qw/ domain org_name email begin end report_id / ],
+        policy  => [ qw/  / ],
+        records => [ qw/  / ],
+    );
+#warn Dumper($meta); ## no critic (Carp)
+    foreach my $k ( keys %required ) {
+        foreach my $f ( @{ $required{$k} } ) {
+            croak "missing $k, $f" if 'policy'  eq $k && ! $policy->{$f};
+            croak "missing $k, $f" if 'meta'    eq $k && ! $meta->$f;
+            croak "missing $k, $f" if 'records' eq $k && ! $records->{$f};
+        };
+    };
+
+    my $rid = $self->insert_author_report($meta,$policy) or croak "failed to create report!";
 
     foreach my $rec ( @$records ) {
         next if ! $rec;
 
-        my $row_id = $self->insert_report_row(
-                $self->{report_id},
-                { map { $_ => $self->dmarc->$_ } qw/ source_ip header_from envelope_to envelope_from / },
-                $self->dmarc->result,
+        my $row_id = $self->insert_report_row( $rid,
+                { map { $_ => $rec->{identifiers}{$_} } qw/ source_ip header_from envelope_to envelope_from / },
+                { map { $_ => $rec->{policy_evaluated}{$_} } qw/ disposition dkim spf / },
                 ) or croak "failed to insert row";
 
-        my $reason = $self->dmarc->result->reason;
-        if ( $reason && $reason->type ) {
-            $self->insert_rr_reason($row_id, $reason->type, $reason->comment );
+# TODO
+        my $reason = $rec->{reason};
+        if ( $reason && $reason->{type} ) {
+            $self->insert_rr_reason($row_id, $reason->{type}, $reason->{comment} );
         };
 
-        my $spf = $self->dmarc->spf;
-        if ( $spf ) {
-            $self->insert_rr_spf( $row_id, $spf );
+        my $spf_ref = $rec->{auth_results}{spf};
+        if ($spf_ref && scalar @$spf_ref ) {
+            foreach my $spf ( @$spf_ref ) {
+                $self->insert_rr_spf( $row_id, $spf );
+            };
         };
 
-        my $dkim = $self->dmarc->dkim;
+        my $dkim = $rec->{auth_results}{dkim};
         if ( $dkim ) {
             foreach my $sig ( @$dkim ) {
                 $self->insert_rr_dkim($row_id, $sig);
@@ -49,12 +66,13 @@ sub save_author {
 
 sub save_receiver {
     my $self = shift;
+# Reports we generate locally, while receiving email
     $self->{dmarc} = shift or croak "missing object with DMARC results\n";
     my $too_many = shift and croak "invalid arguments";
 
-    $self->insert_receiver_report or croak "failed to create report!";
+    my $rid = $self->insert_receiver_report or croak "failed to create report!";
     my $row_id = $self->insert_report_row(
-            $self->{report_id},
+            $rid,
             { map { $_ => $self->dmarc->$_ } qw/ source_ip header_from envelope_to envelope_from / },
             $self->dmarc->result,
             ) or croak "failed to insert row";
@@ -76,8 +94,7 @@ sub save_receiver {
         };
     };
 
-#warn Dumper($self->{dmarc});
-    return $self->{report_row_id};
+    return $row_id;
 };
 
 sub retrieve {
@@ -127,7 +144,7 @@ sub dmarc { return $_[0]->{dmarc}; };
 
 sub get_domain_id {
     my ($self, $domain) = @_;
-    croak "missing domain!" if ! $domain;
+    croak "missing domain calling ".(caller(0))[3] if ! $domain;
     my $r = $self->query('SELECT id FROM domain WHERE domain=?', [$domain]);
     if ( $r && scalar @$r ) {
         return $r->[0]{id};
@@ -136,14 +153,16 @@ sub get_domain_id {
 };
 
 sub get_author_id {
-    my ($self, $author, $email) = @_;
-    croak "missing author name" if ! $author;
-    my $r = $self->query('SELECT id FROM author WHERE org_name=?', [$author]);
+    my ($self, $meta) = @_;
+    croak "missing author name" if ! $meta->org_name;
+    my $r = $self->query('SELECT id FROM author WHERE org_name=?', [$meta->org_name]);
     if ( $r && scalar @$r ) {
         return $r->[0]{id};
     };
-    carp "missing email" if ! $email;
-    return $self->query('INSERT INTO author (org_name,email) VALUES (??)', [$author, $email]);
+    carp "missing email" if ! $meta->email;
+    return $self->query('INSERT INTO author (org_name,email,extra_contact) VALUES (??)',
+            [ $meta->org_name, $meta->email, $meta->extra_contact_info ]
+        );
 };
 
 sub insert_rr_reason {
@@ -197,16 +216,16 @@ EO_ROW_INSERT
 };
 
 sub insert_author_report {
-    my ($self, $meta, $pub) = @_;
+    my ($self, $meta, $pub_pol) = @_;
 
 # check if report exists
-    my $rcpt_dom_id = $self->get_domain_id( $meta->{domain} );
-    my $author_id   = $self->get_author_id($meta->{org_name}, $meta->{email});
-    my $from_dom_id = $self->get_domain_id( $pub->{domain} );
+    my $rcpt_dom_id = $self->get_domain_id( $meta->domain );
+    my $author_id   = $self->get_author_id( $meta );
+    my $from_dom_id = $self->get_domain_id( $pub_pol->domain );
 
     my $ids = $self->query(
         'SELECT id FROM report WHERE rcpt_domain_id=? AND uuid=? AND author_id=?',
-        [ $rcpt_dom_id, $meta->{id} || $meta->{report_id}, $author_id ]
+        [ $rcpt_dom_id, $meta->report_id, $author_id ]
         );
 
     if ( scalar @$ids ) {
@@ -217,10 +236,10 @@ sub insert_author_report {
 # report for this author_domain does not exist, insert new
     my $rid = $self->{report_id} = $self->query(
         'INSERT INTO report (from_domain_id, rcpt_domain_id, begin, end, author_id) VALUES (??)',
-        [ $from_dom_id, $rcpt_dom_id, $meta->{begin}, $meta->{end}, $author_id ]
+        [ $from_dom_id, $rcpt_dom_id, $meta->begin, $meta->end, $author_id ]
     ) or return;
 
-    $self->insert_report_published_policy($rid,$pub);
+    $self->insert_report_published_policy($rid,$pub_pol);
     return $rid;
 };
 
@@ -229,7 +248,10 @@ sub insert_receiver_report {
 
     my $from_id = $self->get_domain_id($self->dmarc->header_from) or croak "missing header_from!";
     my $rcpt_id = $self->get_domain_id($self->dmarc->envelope_to);
-    my $author_id = $self->get_author_id($self->config->{organization}{org_name});
+    my $meta = $self->dmarc->report->meta;
+    $meta->org_name( $self->config->{organization}{org_name} );
+    $meta->email( $self->config->{organization}{email} );
+    my $author_id = $self->get_author_id( $meta );
 
     my $ids = $self->query(
         'SELECT id FROM report WHERE from_domain_id=? AND end > ?',
@@ -258,12 +280,9 @@ sub insert_report_published_policy {
     my $query = 'INSERT INTO report_policy_published (report_id, adkim, aspf, p, sp, pct, rua) VALUES (?,?,?,?,?,?,?)';
     return $self->query( $query, [
             $id,
-            $pub->adkim,
-            $pub->aspf,
-            $pub->p,
-            $pub->sp,
-            $pub->pct,
-            $pub->rua,
+            $pub->{adkim}, $pub->{aspf},
+            $pub->{p},     $pub->{sp},
+            $pub->{pct},   $pub->{rua},
             ]
             ) or croak "failed to insert published policy";
 };
@@ -271,7 +290,7 @@ sub insert_report_published_policy {
 sub db_connect {
     my $self = shift;
 
-    return $self->{dbh} if $self->{dbh};   # caching
+    return $self->{dbix} if $self->{dbix};   # caching
 
     my $dsn  = $self->config->{report_store}{dsn} or croak;
     my $user = $self->config->{report_store}{user};
@@ -287,19 +306,30 @@ sub db_connect {
         };
     };
 
-    $self->{dbh} = DBIx::Simple->connect( $dsn, $user, $pass )
+    $self->{dbix} = DBIx::Simple->connect( $dsn, $user, $pass )
         or return $self->error( DBIx::Simple->error );
 
     if ( $needs_tables ) {
         $self->apply_db_schema($needs_tables);
     };
-    return $self->{dbh};
+    return $self->{dbix};
 };
 
+sub db_check_err {
+    my ($self, $err) = @_;
+    ## no critic (PackageVars)
+    return if ! defined $DBI::errstr;
+    return if ! $DBI::errstr;
+    return if $DBI::errstr eq 'DBI error: ';
+    croak $err . $DBI::errstr;
+};
+
+sub dbix { return $_[0]->{dbix}; };
+
 sub apply_db_schema {
     my ($self, $file) = @_;
     my $setup = $self->slurp($file);
-    foreach ( split /;/, $setup ) { $self->{dbh}->query($_); };
+    foreach ( split /;/, $setup ) { $self->dbix->query($_); };
     return;
 };
 
@@ -336,77 +366,61 @@ sub query {
 
 sub query_any {
     my ($self, $query, $err, @params) = @_;
-    my $dbix = $self->{dbh} or croak "no DB handle";
-    my $r;
-    eval { $r = $dbix->query( $query, @params )->hashes } or do {
-        carp $err . $dbix->error if $dbix->error ne 'DBI error: ';
-    };
-    carp "$err\n$@\n" if $@;
+    my $r = $self->dbix->query( $query, @params )->hashes or croak $err;
+    $self->db_check_err($err);
     return $r;
 };
 
 sub query_insert {
     my ($self, $query, $err, @params) = @_;
-    my $dbix = $self->{dbh};
+    $self->dbix->query( $query, @params ) or croak $err;
+    $self->db_check_err($err);
+
+    # If the table has no autoincrement field, last_id is zero
     my (undef,undef,$table) = split /\s+/, $query;
     ($table) = split( /\(/, $table) if $table =~ /\(/;
-    eval { $dbix->query( $query, @params ); } or do {
-        carp $dbix->error if $dbix->error ne 'DBI error: ';
-    };
-    if ( $@ ) { carp "$@\n$err"; return; };
-    # If the table has no autoincrement field, last_id is zero
-    return $dbix->last_insert_id( undef, undef, $table, undef );
+    croak "unable to determine table in query: $query" if ! $table;
+    return $self->dbix->last_insert_id( undef, undef, $table, undef );
 };
 
 sub query_replace {
     my ($self, $query, $err, @params) = @_;
-    my $dbix = $self->{dbh};
-    eval { $dbix->query( $query, @params ) } or do {
-        carp $dbix->error if $dbix->error ne 'DBI error: ';
-        return;
-    };
-    if ( $@ ) { carp "$@\n$err"; return; };
+    $self->dbix->query( $query, @params ) or croak $err;
+    $self->db_check_err($err);
     return 1;  # sorry, no indication of success
 };
 
 sub query_update {
     my ($self, $query, $err, @params) = @_;
-    my $dbix = $self->{dbh};
-    eval { $dbix->query( $query, @params ) } or do {
-        carp $dbix->error if $dbix->error ne 'DBI error: ';
-        return;
-    };
-    if ( $@ ) { carp "$@\n$err"; return; };
+    $self->dbix->query( $query, @params ) or croak $err;
+    $self->db_check_err($err);
     return 1;
 };
 
 sub query_delete {
     my ($self, $query, $err, @params) = @_;
-    my $dbix = $self->{dbh};
-    $dbix->query( $query, @params ) or do {
-        carp $err . $dbix->error if $dbix->error ne 'DBI error: ';
-        return;
-    };
+    $self->dbix->query( $query, @params ) or croak $err;
+    $self->db_check_err($err);
     my $affected = 0;
-    eval { $affected = $dbix->query("SELECT ROW_COUNT()")->list }; ## no critic (Eval)
+    eval { $affected = $self->dbix->query("SELECT ROW_COUNT()")->list }; ## no critic (Eval)
     return 1 if $@;  # succeed for SQLite
     return $affected;
 };
 
 
 1;
-# ABSTRACT: Store DMARC reports
+# ABSTRACT: SQL storage for DMARC reports
 
 
 =pod
 
 =head1 NAME
 
-Mail::DMARC::Report::Store::SQL - Store DMARC reports
+Mail::DMARC::Report::Store::SQL - SQL storage for DMARC reports
 
 =head1 VERSION
 
-version 0.20130517
+version 0.20130520
 
 =head1 DESCRIPTION
 
@@ -416,7 +430,7 @@ Working and tested with SQLite and MySQL.
 
 =head1 SYPNOSIS
 
-Retreive DMARC reports from SQL data store
+Store and retrieve DMARC reports from SQL data store.
 
 =head1 AUTHORS
 
